@@ -31,7 +31,7 @@ Usage::
     list_simulation_jobs_paginator: ListSimulationJobsPaginator = client.get_paginator("list_simulation_jobs")
     ```
 """
-from mypy_boto3_robomaker.client import RoboMakerClient, RoboMakerClient as Client
+from mypy_boto3_robomaker.client import RoboMakerClient
 from mypy_boto3_robomaker.paginator import (
     ListDeploymentJobsPaginator,
     ListFleetsPaginator,
@@ -42,6 +42,8 @@ from mypy_boto3_robomaker.paginator import (
     ListSimulationJobsPaginator,
 )
 
+Client = RoboMakerClient
+
 
 __all__ = (
     "Client",
